import QtQuick 1.1
import "../common"
import "../../scripts/buddy.js" as BuddyJs;

Rectangle {
    id: root
    width: 400
    height: 500
    border.width: 1
    border.color: "white"
    radius: 5
    property int b_id: 0

    property int label_username_font_size: 20
    property int label_chips_font_size: 20
    property alias button_delete: btnDelete
    property alias image_avatar: imgAvatar
    property alias label_chips: txtChips
    signal deleteBuddy(int b_id)

    color: "black"
    Connections {
        id: myAppConnection
        target: myApp
        onBuddyGotDetail: {
            lvDetailIndicator.on = false;
            var jsonObject = JSON.parse(data);
            if (jsonObject.result === "ok") {
                txtBuddyName.text = jsonObject.name;
                imgAvatar.source = myApp.getAvatarImagePath(jsonObject.avatar);
                txtChips.text = jsonObject.chips;
                btnApprove.visible = false;
                btnDelete.visible = false;
                if (jsonObject.status === 1) {
                    //PENDING
                    btnApprove.visible = true;
                }
                if (jsonObject.status === 3) {
                    btnDelete.visible = true;
                }
            }
        }
    }

    Flipable {
        id: rectName
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: imgAvatar.bottom
        anchors.topMargin: 10

        width: 300
        height: 40
        property bool flipped: false

        back: Rectangle {
            anchors.fill: parent
            color: "white"
            TextInput {
                id:  inputName
                focus: false
                cursorVisible: true
                color: "black"
                font.pixelSize: root.label_username_font_size
                width: parent.width
                height: parent.height
                onAccepted: {
                    inputName.closeSoftwareInputPanel();
                    BuddyJs.changeBuddyName(b_id, inputName.text);
                    focus = false
                    rectName.flipped = !rectName.flipped;
                }
            }
        }

        front: Rectangle {
            anchors.fill: parent
            color: "black"
            Text {
                id: txtBuddyName
                color: "white"
                anchors.centerIn: parent
                font.pixelSize: root.label_username_font_size
            }
            NumberAnimation on opacity {
                duration: 1500
                from: 0.4
                to: 1
                easing.type: Easing.InOutQuad
                loops: Animation.Infinite
                id: animateBlind
            }

        }

        transform: Rotation {
            id: rotation
            origin.x: rectName.width / 2
            origin.y: rectName.height / 2
            axis.x: 1
            axis.y: 0
            axis.z: 0
            angle: 0
        }

        states: State {
            name: "back"
            PropertyChanges {
                target: rotation
                angle: 180
            }
            when: rectName.flipped
        }

        transitions: Transition {
            NumberAnimation {
                target: rotation
                property: "angle"
                duration: 140
            }
        }
        MouseArea {
            anchors.fill: parent
            onPressed: {
                animateBlind.stop();
                rectName.flipped = !rectName.flipped;
                if (rectName.flipped) {
                    inputName.selectAll();
                    inputName.forceActiveFocus();
                    inputName.openSoftwareInputPanel();
                }
            }
        }
        Component.onDestruction: {
            inputName.closeSoftwareInputPanel();
        }

    }

    Image {
        id: imgAvatar
        width: 128
        height: 128
        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
    }

    //chips
    Text {
        id: txtChips
        font.pixelSize: 20
        color: "white"
        anchors.top: rectName.bottom
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Rectangle {
        id: btnDelete
        width: 120
        height: 50
        border.width: 1
        border.color: "white"
        radius: 6
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        anchors.horizontalCenter: parent.horizontalCenter
        color: "black"
        visible: false
        property int button_font_size: 20
        Text {
            text: qsTr("Delete")
            color: "white"
            anchors.centerIn: parent
            font.pixelSize: parent.button_font_size
            font.bold: true
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                deleteBuddy(b_id);
            }
        }
    }

    Rectangle {
        id: btnApprove
        width: btnDelete.width
        height: btnDelete.height
        border.width: 1
        border.color: "white"
        radius: 6
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        anchors.horizontalCenter: parent.horizontalCenter
        color: "black"
        visible: false
        Text {
            text: qsTr("Approve")
            color: "white"
            anchors.centerIn: parent
            font.pixelSize: btnDelete.button_font_size
            font.bold: true
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                BuddyJs.approveBuddyRequest(b_id);
                btnApprove.visible = false;
            }
        }
    }

    BusyIndicator {
        anchors.centerIn: parent
        id: lvDetailIndicator
    }

    function load_buddy_detail(id) {
        visible = true;
        b_id = id;
        lvDetailIndicator.on = true;
        BuddyJs.loadBuddyDetail(id);
    }
}
