import QtQuick 1.1
import "../common"
import "../../scripts/buddy.js" as BuddyJs;

Rectangle {
    id: root
    anchors.fill: parent
    color: "black"
    signal back()

    property alias label_title: lblTitle
    property alias buddy_list: lvBuddys
    property alias buddy_list_delegate: buddyListDelegate
    property alias buddy_detail: viewBuddyDetail
    property int buddy_list_item_font_size: 20

    //Label
    Text {
        id: lblTitle
        text: qsTr("Friends")
        font.pixelSize: 14
        color: "white"
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 6
    }


    Item {
        id: btnClose
        width: 48
        height: 48
        anchors.right: parent.right
        anchors.top: parent.top
        Image {
            anchors.centerIn: parent
            source: "../../images/MainMenu/close.png"
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                myApp.goMainMenuPage();
            }
        }
    }

    Connections {
        target: myApp
        onBuddyGotBuddys: {
            lvBusyIndicator.on = false;
            var jsonObject = JSON.parse(data);
            if (jsonObject.result === "ok") {
                for (var x in jsonObject.buddys) {
                    buddysModel.append({
                                           "name": jsonObject.buddys[x].name,
                                           "b_id": jsonObject.buddys[x].b_id
                                       });
                }
                if (jsonObject.buddys.length > 0) {
                    viewBuddyDetail.load_buddy_detail(jsonObject.buddys[0].b_id);
                    lblEmpty.visible = false;
                } else {
                    lblEmpty.visible = true;
                }
            }
        }
    }

    //buddy list
    ListView {
        id: lvBuddys
        anchors.top: btnClose.bottom
        anchors.topMargin: 2
        anchors.left: parent.left
        width: parent.width * 0.4
        height: parent.height - btnClose.height
        clip: true

        model: buddysModel
        delegate: buddyListDelegate
        snapMode: ListView.SnapToItem
        highlight: Rectangle {
            color: "#292828"
            radius: 2
            y: lvBuddys.currentItem.y
            Behavior on y {
                SpringAnimation {
                    spring: 3
                    damping: 0.2
                }
            }
        }
        BusyIndicator {
            anchors.centerIn: parent
            id: lvBusyIndicator
        }
        Text {
            id: lblEmpty
            text: qsTr("Empty")
            color: "white"
            anchors.centerIn: parent
            visible: false
            font.pixelSize: 20
        }
    }


    FriendsModel {
        id: buddysModel
    }

    Component {
        id: buddyListDelegate
        Item {
            width: lvBuddys.width - 20
            height: 40
            Text {
                text: name
                color: "white"
                anchors.centerIn: parent
                font.pixelSize: root.buddy_list_item_font_size
            }
            MouseArea {
                anchors.fill: parent
                onPressed: {
                    lvBuddys.currentIndex = index;
                    viewBuddyDetail.load_buddy_detail(b_id);
                }
            }
            //            Rectangle {
            //                width: parent.width
            //                height: 1
            //                color: "white"
            //                anchors.left: parent.left
            //                anchors.bottom: parent.bottom
            //            }

        }
    }

    //buddy detail
    BuddyDetailView {
        id: viewBuddyDetail
        anchors.top: btnClose.bottom
        anchors.left: lvBuddys.right
        anchors.leftMargin: 2
        width: parent.width - lvBuddys.width - 20
        height: parent.height - btnClose.height - 20
        onDeleteBuddy: {
            delete_buddy(b_id);
        }
    }



    Component.onCompleted: {
        load_buddys_from_server();
        //        console.log("load buddys from db");
        //        console.log("98");
        //        lvBuddys.positionViewAtIndex(lvBuddys.count -1, ListView.Beginning)
        //        if (lvBuddys.currentIndex >= 0) {
        //            console.log(buddysModel.get(lvBuddys.currentIndex).b_id);
        //        }
    }

    function load_buddys_from_server() {
        lvBusyIndicator.on = true;
        BuddyJs.loadBuddys();
    }

    function delete_buddy(id) {
        console.log("onDeleteBuddy " + id);
        BuddyJs.deleteBuddyRequest(id);
        //delete buddy from model
        viewBuddyDetail.visible = false;
        buddysModel.deleteByIndex(lvBuddys.currentIndex);
    }

}
