import QtQuick 1.1
import "../common"
import "../../scripts/leaderboards.js" as LBDJs

Item {
    id: root
    width: 400
    height: 320
    signal myinfo(variant chips, int rank, int offset)

    property int row_height: 32
    property int rank_width: 20
    property int username_width: 240
    property int chips_width: 100
    property int offset_width: 60
    property int client_width: 10
    property int country_width: 10
    property int font_size_username: 16
    property int font_size_status: 12
    property int font_size_chips: 14
    property int font_size_offset: 16

    ListModel {
        id: modelTop20
    }

    ListView {
        anchors.fill: parent
        clip: true
        model: modelTop20
        delegate: Component {
            Rectangle {
                width: ListView.view.width
                height: root.row_height
                color: index % 2 ? "black":"#292828"
                border.width: 1
                border.color: Qt.lighter(color);
                Row {
                    width: parent.width
                    height: parent.height
                    spacing: 2
                    Text {
                        text: rank + "."
                        width: root.rank_width
                        height: parent.height
                        color: "white"
                        verticalAlignment: Text.AlignVCenter
                        horizontalAlignment: Text.AlignRight
                    }
                    Item {
                        width: root.username_width
                        height: parent.height
                        Text {
                            width: parent.width
                            text: name
                            color: "white"
                            font.pixelSize: root.font_size_username
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.top: parent.top
                            horizontalAlignment: Text.AlignHCenter
                        }
                        Text {
                            width: parent.width
                            text: status
                            color: "grey"
                            font.pixelSize: root.font_size_status
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.bottom: parent.bottom
                            horizontalAlignment: Text.AlignHCenter
                        }
                    }
                    Text {
                        text: chips
                        width: root.chips_width
                        height: parent.height
                        color: "white"
                        verticalAlignment: Text.AlignVCenter
                        horizontalAlignment: Text.AlignRight
                        font.pixelSize:  root.font_size_chips
                    }
                    Text {
                        text: offset === 0 ? '' : offset
                        width: root.offset_width
                        height: parent.height
                        color: "white"
                        verticalAlignment: Text.AlignVCenter
                        horizontalAlignment: Text.AlignRight
                        font.pixelSize: root.font_size_offset
                    }
                }
            }
        }

        BusyIndicator {
            id: busyIndicator
            anchors.centerIn: parent
        }


        Component.onCompleted: {
            busyIndicator.start();
            if (myApp.getOfflineMode()) {
                loadTestData();
            } else {
                LBDJs.load_top20_by_chips();
            }
        }
    }

    Connections {
        target: myApp
        onLeaderboardsGotTop20: {
            busyIndicator.stop();
            var jsonObject = JSON.parse(data);
            for (var x in jsonObject.list) {
                var item = jsonObject.list[x];
                modelTop20.append({
                                      "rank": "No." + item.rank,
                                      "name": item.name,
                                      "chips": item.chips,
                                      "offset": item.offset,
                                      "status": item.status,
                                      "country": item.country_id,
                                      "client_type": item.client_type
                                  });
            }

            modelTop20.append(jsonObject.list);
            root.myinfo(jsonObject.chips, jsonObject.rank, jsonObject.offset);
        }
        onLeaderboardsGotDataFailed: {
            console.log("TODO load leaderboards from server faild:" + data);
            busyIndicator.stop();
        }
    }

    function loadTestData() {
        for (var i = 1; i <= 20; i++ ) {
            modelTop20.append({
                                  rank: i,
                                  name: "username " + i,
                                  status: "status " + i,
                                  chips: 12231231231,
                                  offset: -20,
                                  country: 1,
                                  client:2
                              });
        }

        busyIndicator.stop();
    }

}
