import QtQuick 1.1
import "../common"
import "../../scripts/mainmenu.js" as MainMenuJs
import "../../scripts/utils.js" as UtilsJs

Item {
    id: root
    width: 360
    height: 200
    property alias rect_login: rect
    property alias label_title: txtTitle
    property alias edit_username: editUsername
    property alias edit_password: editPassword
    property alias label_password: lblPassword
    property alias label_status: lblStatus
    property int button_width: 80
    property int button_height: 30
    property int button_font_size: 20

    signal signup()
    signal login(string username, string password)
    Rectangle {
        id: backgruond
        anchors.fill: parent
        color: "black"
        opacity: 0.9
    }

    MouseArea {
        anchors.fill: parent
    }

    Rectangle {
        id: rect
        color: myApp.getDebugMode() ? UtilsJs.random_color() : "black"
        width: 360
        height: 170
//        border.width: 1
//        border.color: "darkgrey"
//        radius: 10
        anchors.top: parent.top
        anchors.topMargin: 20
        anchors.horizontalCenter: parent.horizontalCenter
        Text {
            id: txtTitle
            text: qsTr("Sign In")
            anchors.top: parent.top
            anchors.topMargin: 6
            anchors.horizontalCenter: parent.horizontalCenter
            font.pixelSize: 24
            color: "white"
        }

        Text {
            id: lblUsername
            text: qsTr("Email")
            color: "white"
            font.pixelSize: 20
            anchors.top: txtTitle.bottom
            anchors.topMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 20
        }

        Text {
            id: lblPassword
            text: qsTr("Password")
            color: "white"
            font.pixelSize: lblUsername.font.pixelSize
            anchors.top: lblUsername.bottom
            anchors.topMargin: 10
            anchors.left: lblUsername.left
        }


        InputBox {
            id: editUsername
            anchors.verticalCenter: lblUsername.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: 10
            width: 240
            height: 30
            pixelSize: root.button_font_size
            onAccepted: {
                editPassword.activeFocus();
            }
        }

        InputBox {
            id: editPassword
            anchors.left: editUsername.left
            anchors.verticalCenter: lblPassword.verticalCenter
            width: editUsername.width
            height: editUsername.height
            pixelSize: root.button_font_size
            password: true
            onAccepted: {
                _login();
            }
        }


        Text {
            id: lblStatus
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: editPassword.bottom
            anchors.topMargin: 4
            font.pixelSize: 18
            color: "white"
            text: myApp.getDebugMode() ? "TEXT for TEST" : ""
            visible: myApp.getDebugMode() ? true : false
        }

        Row {
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 4
            anchors.horizontalCenter: parent.horizontalCenter
            width: root.button_width * 4 + spacing * 3
            height: root.button_height
            spacing: 6
            Button {
                height: parent.height
                width: root.button_width
                text: qsTr("Sign Up")
                pixelSize: root.button_font_size
                onClicked: {
                    root.signup();
                    close();
                }
            }
            Button {
                height: parent.height
                width: root.button_width
                text: qsTr("Login")
                pixelSize: root.button_font_size
                onClicked: {
                    _login();
                }
            }
            Button {
                height: parent.height
                width: root.button_width
                text: qsTr("Forgot")
                pixelSize: root.button_font_size
                onClicked: {
                    Qt.openUrlExternally("http://account.piegames.net/forgot");
                }
            }
            Button {
                height: parent.height
                width: root.button_width
                text: qsTr("Support")
                pixelSize: root.button_font_size
                onClicked: {
                    Qt.openUrlExternally("mailto:support@piegames.net?subject=help " + myApp.mainmenuGetUUID() + "&body=");
                }
            }

        }
    }

    function close() {
        lblStatus.text = "";
        lblStatus.visible = false;
        visible = false;
    }

    function open(s) {
        editUsername.text = myApp.loginLoadUsername();
        editPassword.text = myApp.loginLoadPassword();
        if (s !== undefined) {
            lblStatus.text = s;
            lblStatus.visible = true;
        }

        visible = true;
    }

    function _login() {
        editUsername.text = MainMenuJs.fixEmail(editUsername.text);
        editUsername.closeSoftwareInputPanel();
        editPassword.closeSoftwareInputPanel();
        root.login(editUsername.text, editPassword.text);
        close();
    }
}
