import QtQuick 1.1
import PIEQuick 1.0
import "../common"
import "../../scripts/mainmenu.js" as MainMenuJs

Rectangle {
    id: root
    anchors.fill: parent
    color: "black"
    property int step: 0

    property alias versionInfo: versionInfo
    property alias imgGirl: imageGirl
    property alias navigator: navigator
    property int navigator_font_size: 24
    property int navigator_button_width: 180
    property alias myInfo: myInfo
    property int myinfo_name_font_size: 28
    property int myinfo_chips_font_size: 24
    property alias shortcutButtons: shortcutButtons
    property bool menuClicked: false
    property alias dialog_connection: dlgConnection
    property alias dialog_login: dlgLogin
    property alias dialog_error: dlgError
    property alias dialog_signup: dlgSignup
    property alias dialog_update: dlgUpdate
    property alias button_test: btnTest

    Image {
        id: imageGirl
        source: "../../images/MainMenu/bg.png"
        height: parent.height
        width: height
        anchors.right: parent.right
    }

    Connections {
        target: myApp
        onMainmenuConnectionDialogShow: {
            navigator.visible = false;
            dlgConnection.show(s);
        }
        onMainmenuConnectionDialogHide: {
            dlgConnection.hide();
            navigator.visible = true;
        }
        onMainmenuLoginDialogShow: {
            dlgConnection.hide();
            dlgLogin.open();
        }
        onMainmenuUpdateDialogShow: {
            dlgUpdate.open(qsTr("New update released ") + "!", qsTr("Click to download & install the latest update..."))
        }
        onMainmenuErrorDialogShow: {
            dlgConnection.hide();
            dlgError.open(title, message);
        }
        onMainmenuLoginFailed: {
            dlgLogin.open(qsTr("No such user or password mismatch"));
        }
        onMainmenuGotMyInfo: {
            myInfo.load(data.username, data.chips, data.avatar)
        }
    }

    VersionInfo {
        id: versionInfo
        onClicked: {
            myApp.goResearchPage();
        }
    }


    ShortcutButtons {
        id: shortcutButtons
        anchors.top: parent.top
        anchors.topMargin: 2
        anchors.right: parent.right
        anchors.rightMargin: 2
        onSettings: {
            myApp.goSettingsPage();
        }
        onStore: {
            myApp.goStorePage();
        }
        onHelp: {
            myApp.goHelpPage();
        }
        onClose: {
            myApp.goQuit();
        }
    }

    Navigator {
        id: navigator
        width: 400
        height: 180
        fontSize: root.navigator_font_size
        buttonWidth: root.navigator_button_width
        visible: !dlgLogin.visible && !dlgConnection.visible
        onPlaynow: {
            if (menuClicked)
                return;
            myApp.mainmenuPlayNow();
        }
        onLeaderboards: {
            if (menuClicked)
                return;
            myApp.goLeaderboardsPage();
        }
        onFriends: {
            if (menuClicked)
                return;
            myApp.goFriendsPage();
        }
        onSupport: {
            if (menuClicked)
                return;
            myApp.goSupportPage();
        }
    }

    //my info
    MyInfo {
        id: myInfo
        label_name.font.pixelSize: root.myinfo_name_font_size
        label_chips.font.pixelSize: root.myinfo_chips_font_size
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        visible: false
    }

    ConnectionDialog {
        id: dlgConnection
        visible: false
        anchors.centerIn: parent
    }

    LoginDialog {
        id: dlgLogin
        anchors.fill: parent
        visible: false
        onSignup: {
            dlgSignup.show();
        }
        onLogin: {
            myApp.loginSaveUsername(username);
            myApp.loginSavePassword(password);
            MainMenuJs.loadMyInfo();
        }
    }
    RegistrationDialog {
        id: dlgSignup
        anchors.fill: parent
        visible: false
        onBack: {
            dlgSignup.close();
            dlgLogin.open();
        }
    }
    QueryDialog {
        id: dlgUpdate
        anchors.centerIn: parent
        text_cancel: qsTr("Cancel")
        text_ok: qsTr("Ok")
        visible: false
        onCancel: {
            close();
            dlgLogin.open();
        }
        onOk: {
            Qt.openUrlExternally(myApp.mainmenuGetUpdateUrl());
        }
    }

    QueryDialog {
        id: dlgError
        anchors.centerIn: parent
        text_cancel: ""
        text_ok: qsTr("OK")
        visible: false
        onOk: {
            close();
        }
    }

    Button {
        id: btnTest
        text: "X"
        height: 40
        width: height
        visible: myApp.getOfflineMode()
        anchors.top: parent.top
        anchors.topMargin: 10
        anchors.horizontalCenter: parent.horizontalCenter
        onClicked: {
            test()
        }
    }

    HttpUploader {
        id: uploader
        onUploadStateChanged: {
            if (uploadState === HttpUploader.Done) {
                try {
                    var r = JSON.parse(uploader.responseText);
                    myApp.settingsSaveAvatar(1, r.url);
                    uploader.clear();
                } catch (e) {
                    return;
                }
                myApp.settingsAvatarClearUpdateFlag();
            }
        }

        Component.onCompleted: {
            if (myApp.settingsIsAvatarNeedUpdate()) {
                open("http://holdem2.piegames.net/profile.php?v=1.0&action=upload");
                addField("u", encodeURIComponent(myApp.loginLoadUsername()));
                addField("p", encodeURIComponent(myApp.loginGetPasswordHash()));
                addFile("fileToUpload", myApp.settingsGetAvatarUrl());
                send();
            }
        }
    }

    Component.onCompleted: {
        if (myApp.authdIPsCount() === 0 && !myApp.getOfflineMode()) {
            loadServerList();
        }
    }

    function test() {
        step++;
        switch (root.step) {
        case 1:
            myInfo.load("test user", 1231231231231, 4);
            break;
        case 2:
            dlgError.open("Error", "Server shutdown for maintenance");
            break;
        case 3:
            dlgLogin.open("no such user or password mismatch");
            break;
        case 4:
            dlgSignup.show();
            break;
        case 5:
            dlgUpdate.open("Update available", "please download the new update form our site");
            break;
        case 6:
            dlgConnection.show("Connecting to servers...");
            break;
        }
    }

    //terms & privacy
    //    Component.onDestruction: {
    //        console.log("mainmenu onDestruction");
    //    }
    function loadServerList() {
        dlgConnection.show("Connecting to servers...");
        if (myApp.getDebugMode()) {
            MainMenuJs.loadServrListDebug();
        } else {
            MainMenuJs.loadServerList();
        }
    }

    function openPaypal() {
        var url = "http://store.piegames.net/paypal/shop.php?proto=" + myApp.storeGetProtocalVersion() + "&ch=" + myApp.getChannel()+"&co="+myApp.getCompany()+"&u="+myApp.loginLoadUsername()+"&c="+myApp.getClientType()+"&game="+myApp.getGame()+"&version=" + myApp.getVersionInfo();
        Qt.openUrlExternally(url);
    }
}
