import QtQuick 1.1
import "../common"
import "../../scripts/mainmenu.js" as MainmenuJs

Item {
    id: root
    width: 360
    height: 280
    property alias rect_signup: rect
    property alias label_title: lblTitle
    property alias label_status: lblStatus
    property alias edit_username: editUsername
    property alias label_username: lblUsername
	property int button_height: 30
	property int button_width: 80
	property int button_spacing: 10
	property int button_font_size: 30
    signal back()
    property bool isSubmitting: false

    Connections {
        target: myApp
        onMainmenuRegisterSuccess: {
            root.isSubmitting = false;
            myApp.loginSaveUsername(editUsername.text);
            myApp.loginSavePassword(editPassword.text);
            root.back();
        }
        onMainmenuRegisterFailed: {
            root.isSubmitting = false;
            lblStatus.text = err;
        }
    }

    Rectangle {
        anchors.fill: parent
        color: myApp.getDebugMode() ? "red" : "black"
        opacity: 0.80
    }

    MouseArea {
        anchors.fill: parent
    }

    Item {
        id: btnClose
        anchors.right: parent.right
        anchors.top: parent.top
        width: 64
        height: 64
        Image {
            width: 48
            height: 48
            anchors.centerIn: parent
            source: "../../images/MainMenu/close.png"
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                Qt.quit();
            }
        }
    }

    Text {
        id: lblStatus
        color: "white"
        font.pixelSize: 24
        text: myApp.getDebugMode() ? "TEST" : ""
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: rect.top
        anchors.bottomMargin: 20
    }

    Rectangle {
		id: rect
        color: "black"
        width: 420
        height: 200
        radius: 10
        anchors.centerIn: parent
        border.color: "white"
        border.width: 1
        Text {
            id: lblTitle
            text: qsTr("New account")
            anchors.top: parent.top
            anchors.topMargin: 6
            anchors.horizontalCenter: parent.horizontalCenter
            font.pixelSize: 24
            color: "white"
        }

        Text {
            id: lblUsername
            text: qsTr("Email")
            color: "white"
            font.pixelSize: 20
            anchors.top: lblTitle.bottom
            anchors.topMargin: 10
            anchors.left: parent.left
            anchors.leftMargin: 20
            width: 100
        }

        Text {
            id: lblPassword
            text: qsTr("Password")
            color: "white"
            font.pixelSize: lblUsername.font.pixelSize
            anchors.top: lblUsername.bottom
            anchors.topMargin: 20
            anchors.left: lblUsername.left
            width: lblUsername.width
        }

        Text {
            id: lblPassword2
            text: qsTr("Password2")
            color: "white"
            font.pixelSize: lblUsername.font.pixelSize
            anchors.top: lblPassword.bottom
            anchors.topMargin: lblPassword.anchors.topMargin
            anchors.left: lblUsername.left
            width: lblUsername.width
        }

        InputBox {
            id: editUsername
            width: 300
            height: lblUsername.height * 1.1
            pixelSize: 20
            anchors.verticalCenter: lblUsername.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: 20
            onActive: {
            }
            onInactive: {
            }
        }

        InputBox {
            id: editPassword
            width: editUsername.width
            height: editUsername.height
            pixelSize: editUsername.pixelSize
            anchors.verticalCenter: lblPassword.verticalCenter
            anchors.right: editUsername.right
            password: true
            onActive: {
                rect.anchors.top = root.top;
            }
            onInactive: {
                rect.anchors.centerIn = root;
            }
        }
        InputBox {
            id: editPassword2
            width: editUsername.width
            height: editUsername.height
            pixelSize: editUsername.pixelSize
            anchors.verticalCenter: lblPassword2.verticalCenter
            anchors.right: editUsername.right
            password: true
            onActive: {
                rect.anchors.top = root.top;
            }
            onInactive: {
                rect.anchors.centerIn = root;
            }
        }

        Row {
            width: root.button_width * 2 + spacing
            height: root.button_height + 10
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: root.button_spacing

            Button {
                id: btnRegister
                width: root.button_width
                height: parent.height
                fontNormalColor: "white"
                fontHighlightColor: "black"
                normalColor: "black"
                hightlightColor: "white"
                text: qsTr("Register")
                pixelSize: 20
                onClicked: {
                    if (root.isSubmitting)
                        return;
                    editUsername.text = MainmenuJs.fixEmail(editUsername.text);
                    editUsername.closeSoftwareInputPanel();
                    if (editPassword.text === editPassword2.text) {
                        root.isSubmitting = true;
                        lblStatus.text = "";
                        MainmenuJs.register(editUsername.text, editPassword.text);
                    } else {
                        lblStatus.text = qsTr("password mismatch");
                    }
                }
            }

            Button {
                id: btnBack
                width: root.button_width
                height: parent.height
                fontNormalColor: "white"
                fontHighlightColor: "black"
                normalColor: "black"
                hightlightColor: "white"
                text: qsTr("Back")
                pixelSize: 20
                onClicked: {
                    root.back();
                }
            }
        }


        BusyIndicator {
            id: busyIndicator
            anchors.centerIn: parent
        }
    }

    function show() {
        editUsername.text = "";
        editPassword.text = "";
        editPassword2.text = "";
        visible = true;
    }

    function close() {
        visible = false;
    }
}
