import QtQuick 1.1

import "../common"
import "../../scripts/utils.js" as UtilsJs

Item {
    id: root
    anchors.fill: parent
    visible: false
    property int avatar_type: 0
    property string avatar_url: ""
    property alias grid_avatar: grid
    property alias rect_grid: rectGrid
    property alias button_save: btnSave
    property alias button_close: btnClose
    property alias button_upload: btnUpload
    property alias dialog_preview: dlgFolderPreview
    property alias label_upload: lblUpload
    property alias image_preview: imgPreview
    signal save(int avatar_type, string avatar_url)

    Rectangle {
        anchors.fill: parent
        color: myApp.getDebugMode() ? UtilsJs.random_color() : "black"
        opacity: 0.9
    }

    Rectangle {
        id: rectGrid
        width: parent.width - btnClose.width
        height: parent.height - btnClose.height
        color: myApp.getDebugMode() ? UtilsJs.random_color() : "black"
        anchors.centerIn: parent
        GridView {
            id: grid
            width: parent.width
            height: parent.height - 40 - btnUpload.height
            anchors.top: parent.top
            anchors.topMargin: 10
            clip: true
            model: 80
            cellHeight: 70
            cellWidth: cellHeight
            delegate: numberDelegate
            highlight: Rectangle {
                color: "yellow"
                width: grid.cellWidth
                height: width
                x: grid.currentItem.x
                y: grid.currentItem.y
                Behavior on x {
                    SpringAnimation {
                        spring: 3
                        damping: 0.2
                    }
                }
                Behavior on y {
                    SpringAnimation {
                        spring: 3
                        damping: 0.2
                    }
                }
            }
            Component.onCompleted: {
                grid.currentIndex = myApp.settingsGetAvatarId() -1;
            }
        }
        Component {
            id: numberDelegate
            Item {
                width: grid.cellWidth
                height: width
                AnimatedImage {
                    width: parent.width - 6
                    height: width
                    anchors.centerIn: parent
                    source: index < 64 ?  "../../images/Avatar/" + (index + 1) + ".png" : "../../images/Avatar/" + (index + 1) + ".gif"
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        grid.currentIndex = index;
                        root.avatar_type = 0;
                        root.avatar_url = index + 1;
                    }
                }
            }
        }
        Image {
            id: imgPreview
            visible: source !== ""
            height: 40
            width: height
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            sourceSize.width: width
            sourceSize.height: height
            source: myApp.getOfflineMode() ? "../../images/Avatar/64.png" : ""
        }
        Text {
            id: lblUpload
            text: qsTr("Upload your picture (read storage permisstion is needed)")
            color: "white"
            anchors.verticalCenter: btnUpload.verticalCenter
            anchors.right: btnUpload.left
            anchors.rightMargin: 20
        }
        Button {
            id: btnUpload
            anchors.bottom: btnSave.bottom
            anchors.right: btnSave.left
            anchors.rightMargin: 40
            width: btnSave.width
            height: btnSave.height
            text: qsTr("Load")
            onClicked: {
                dlgFolderPreview.open();
            }
        }
        Button {
            id: btnSave
            anchors.bottom: parent.bottom
            anchors.right: parent.right
            anchors.rightMargin: 10
            anchors.bottomMargin: 10
            height: 40
            text: qsTr("ok")
            onClicked: {
                root.save(root.avatar_type, root.avatar_url);
                root.close();
            }
        }
        FolderPreviewDialog {
            id: dlgFolderPreview
            height: root.height - btnClose.height
            onSelect: {
                root.avatar_type = 1;
                imgPreview.source = url;
                root.avatar_url = url;
            }
        }
    }

    //close button
    ImageButton {
        id: btnClose
        height: 48
        width: height
        source: "../../images/MainMenu/close.png"
        anchors.right: parent.right
        anchors.top: parent.top
        onPressed: {
            root.close();
        }
    }

    function open() {
        root.visible = true;
    }

    function close() {
        dlgFolderPreview.close();
        root.visible = false;
    }
}
