import QtQuick 1.1
import Qt.labs.folderlistmodel 1.0

import "../common"
import "../../scripts/utils.js" as UtilsJs

Item {
    id: root
    anchors.fill: parent
    visible: false
    property alias grid_preview: grid
    signal select(string url)
    Rectangle {
        anchors.fill: parent
        color: "black"
        opacity: 0.92
    }

    FolderListModel {
        id: folderModel
        showDotAndDotDot: true
        showOnlyReadable: true
        showDirs: true
        nameFilters: ["*.jpg", "*.png"]
    }

    Component {
        id: fileDelegate
        Item {
            height: grid.cellHeight
            width: height
                Image {
                    id: image
                    width: grid.cellWidth
                    height: grid.cellWidth
                    fillMode: Image.PreserveAspectFit
                    asynchronous: true
                    //don't user sourceSize when use Image
                    sourceSize.width: grid.cellWidth
                    sourceSize.height: grid.cellHeight
                }
                Text {
                    id: txtFileName
                    text: folderModel.isFolder(index) ? fileName : ""
                    color: "black"
                    anchors.centerIn: parent
                    width: parent.width - 2
                    maximumLineCount: 1
                    wrapMode: Text.WrapAnywhere
                    elide: Text.ElideRight
                    horizontalAlignment: Text.AlignHCenter
                    visible: text !== ""
                }
                Component.onCompleted: {
//                    console.log("filename=" + fileName);
//                    console.log("isFolder=" + folderModel.isFolder(index));
                    if (folderModel.isFolder(index)) {
                        if (fileName === "..") {
                            image.source = "../../images/Settings/folder_up.png"
                        } else {
                            image.source = "../../images/Settings/folder.png";
                        }
                    } else {
                        image.source = filePath;
                    }
                }
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if (folderModel.isFolder(index)) {
                        folderModel.folder = filePath;
                    } else {
                        root.select(filePath);
                        root.close();
                    }
                }
            }
        }
    }

    GridView {
        id: grid
        model: folderModel
        width: parent.width
        height: parent.height
        clip: true
        cellHeight: 100
        cellWidth: cellHeight
        cacheBuffer: 10
        delegate: fileDelegate
    }


    function open() {
        folderModel.folder = myApp.settingsGetLocalPicturePath();

        visible = true;
    }

    function close() {
        visible = false;
    }
}
