import QtQuick 1.1
import "../common"
import "../../scripts/utils.js" as UtilsJs
import "../../scripts/support.js" as SupportJs

Rectangle {
    id: root
    width: 360
    height: 200
    color: myApp.getDebugMode() ? UtilsJs.random_color() : "black"
    property int tab_button_width: 100
    property int tab_button_height: 40
    property int tab_button_font_size: 20
    property string billboard_string: ""
    property int submit_row_height: 40
    property int submit_pixelSize: 24
    property int button_submit_width: 100
    property int button_submit_font_size: 20
    property int my_q_listview_font_size: 20

    Rectangle {
        id: tabBillboard
        width: parent.width
        height: parent.height - buttonbar.height
        anchors.top: parent.top
        anchors.left: parent.left
        border.color: "black"
        border.width: 1
        color: "white"
        visible: btnBillboard.selected
        Flickable {
            anchors.fill: parent
            Text {
                id: txtBillboardMsg
                anchors.centerIn: parent
                font.pixelSize: 20
                color: "black"
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                verticalAlignment: Text.AlignVCenter
                width: parent.width - 20
                text: root.billboard_string
                anchors.margins: 10
                onTextChanged: {
                    parent.contentHeight = txtBillboardMsg.height;
                }
            }
        }

    }
    Rectangle {
        id: tabMyQ
        width: parent.width
        height: parent.height - buttonbar.height
        anchors.top: parent.top
        anchors.left: parent.left
        border.color: "black"
        border.width: 1
        color: "white"
        visible: btnMyQ.selected
        ListView {
            id: listMyQa
            anchors.fill: parent
            clip: true
            model: ListModel{
                id: myQaModel
            }
            delegate: Component {
                Column {
                    Text {
                        width: root.width - 4
                        anchors.left: parent.left
                        anchors.leftMargin: 4
                        text: "<b>Q:</b>" + q
                        horizontalAlignment: Text.AlignLeft
                        wrapMode: Text.WordWrap
                        font.pixelSize: root.my_q_listview_font_size
                    }
                    Text {
                        width: root.width - 4
                        anchors.right: parent.right
                        anchors.rightMargin: 4
                        text: "<b>A:</b>" + a + "<br/>"
                        horizontalAlignment: Text.AlignRight
                        wrapMode: Text.WordWrap
                        font.pixelSize: root.my_q_listview_font_size
                    }
                }
            }
            header: Component {
                Row {
                    id: row
                    width: root.width
                    height: root.submit_row_height
                    spacing: 2
                    InputBox {
                        border.width: 1
                        border.color: "black"
                        width: parent.width - btnSubmit.width - 4
                        height: row.height
                        focus: false
                        pixelSize: root.submit_pixelSize
                        onAccepted: {
                            console.log("send_my_q" + text);
                            SupportJs.send_my_q(msg);
                        }
                    }
                    Button {
                        id: btnSubmit
                        text: qsTr("submit")
                        height: row.height
                        width: root.button_submit_width
                        font.pixelSize: root.button_submit_font_size
                        onClicked: {
                            console.log("submit");
                        }
                    }
                }
            }

            Connections {
                target: myApp
                onSupportGotMy: {
                    myQaModel.clear();
                    var jsonObject = JSON.parse(data);
                    for (var x in jsonObject.data) {
                        myQaModel.append({
                                         "q": jsonObject.data[x].q,
                                         "a": jsonObject.data[x].a
                                     });
                    }
                }
                onSupportSentMyQ: {
                    SupportJs.load_my_qa();
                }
            }

        }


    }


    //button bar
    Rectangle {
        id: buttonbar
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        width: parent.width
        height: root.tab_button_height
        color: "black"
        Rectangle {
            id: btnBillboard
            height: parent.height
            width: root.tab_button_width
            anchors.left: parent.left
            anchors.top: parent.top
            color: "black"
            property bool selected: false

            onSelectedChanged: {
                if (selected) {
                    color = "darkgrey";
                    txtBillboard.color = "white";
                    SupportJs.load_billboard();
                } else {
                    color = "black";
                    txtBillboard.color = "darkgrey";
                }
            }
            Text {
                id: txtBillboard
                text: qsTr("Billboard")
                color: "grey"
                anchors.centerIn: parent
                font.pixelSize: root.tab_button_font_size
            }
            MouseArea {
                anchors.fill: parent
                onPressed: {
                    if (btnBillboard.selected)
                        return;
                    btnBillboard.selected = true;
                    btnMyQ.selected = false;
                }
            }
        }
        Rectangle {
            id: btnMyQ
            height: btnBillboard.height
            width: btnBillboard.width
            anchors.left: btnBillboard.right
            anchors.top: btnBillboard.top
            color: "black"
            property bool selected: false
            onSelectedChanged: {
                if (selected) {
                    color = "darkgrey";
                    txtMyQ.color = "white";
                    SupportJs.load_my_qa();

                } else {
                    color = "black";
                    txtMyQ.color = "darkgrey";
                }
            }
            Text {
                id: txtMyQ
                text: qsTr("My Q&A")
                color: "grey"
                anchors.centerIn: parent
                font.pixelSize: root.tab_button_font_size
            }
            MouseArea {
                anchors.fill: parent
                onPressed: {
                    if (btnMyQ.selected)
                        return;
                    btnMyQ.selected = true;
                    btnBillboard.selected = false;
                }
            }

        }

    }

    Component.onCompleted: {
        btnBillboard.selected = true;
    }

    Connections {
        target: myApp
        onSupportGotBillboard: {
            var jsonObject = JSON.parse(data);
            root.billboard_string = jsonObject.msg;
        }
    }

    function load_billboard() {
        SupportJs.load_billboard();
    }

    function load_my_qa() {
        SupportJs.load_my_qa();
    }


}
