import QtQuick 1.1
import "../common"

Item {
    id: root
    width: 360
    height: 200
    property variant value: 0
    property variant min: 0
    property variant max: 0
    property variant remaining: max - value
    property alias label_value: txt
    property alias chips_list: grid
    property int button_width: 80
    property int button_height: 30
    signal allin();
    signal bet(variant value)
    signal cancel()
    Rectangle {
        anchors.fill: parent
        radius: 10
        color: "black"
        //value
        Rectangle {
            id: lblValue
            width: parent.width * 0.9
            height: txt.font.pixelSize * 1.2
            color: "#1e1b1b"
            radius: 6
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 10
            property alias text: txt
            Text {
                id: txt
                text: root.value
                width: parent.width
                anchors.centerIn: parent
                color: "white"
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 20
            }
        }

        //chips buttons
        GridView {
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: lblValue.bottom
            anchors.topMargin: 10
            id: grid
            width: 6 * cellWidth
            height: cellHeight * 2.5
            cellHeight: 52
            cellWidth: cellHeight
            clip: true
            model: ListModel {
                ListElement { img:"10M"; value: 10000000}
                ListElement { img: "100k"; value: 100000}
                ListElement { img: "10k"; value: 10000}
                ListElement {img: "2k"; value: 2000}
                ListElement { img: "500"; value: 500}
                ListElement { img: "50"; value: 50}

                ListElement { img: "1M"; value: 1000000}
                ListElement { img: "50k"; value: 50000}
                ListElement { img: "5k"; value: 5000}
                ListElement { img: "1k"; value: 1000}
                ListElement { img: "100"; value: 100}
                ListElement { img: "10"; value: 10}
            }
            delegate: Item {
                width: grid.cellHeight * 0.96
                height: width
                Image {
                    source: "../../images/Chip/" + img + ".png"
                    anchors.fill: parent
                    visible: root.remaining >= value
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            root.value += value;
                            if (root.value > root.max)
                                root.value = root.max;
                        }
                    }
                }
            }
        }


        Row {
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 4
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: 10
            width: root.button_width * 3 + spacing * 3
            height: root.button_height
            Button {
                height: parent.height
                width: root.button_width
                text: root.value > root.min ? qsTr("Reset") : qsTr("Cancel")
                onClicked: {
                    if (root.value > root.min) {
                        root.reset();
                    } else {
                        root.close();
                        root.cancel();
                    }
                }
            }
            Button {
                height: parent.height
                width: root.button_width
                text: qsTr("All-In")
                onClicked: {
                    close();
                    root.allin();
                }
            }
            Button {
                height: parent.height
                width: root.button_width
                text: qsTr("Ok")
                onClicked: {
                    root.bet(root.value);
                    close();
                }
            }
        }
    }
    function show(i_min, i_max) {
        min = i_min;
        value = min;
        max = i_max;
        visible = true;
    }
    function reset() {
        value = min;
    }
    function close() {
        min = 0;
        max = 0;
        value = min;
        visible = false;
    }
 }
