import QtQuick 1.1
import "../../scripts/utils.js" as UtilsJs
import "../common"

Item {
    id: root
    anchors.fill: parent
    property variant min: 0
    property variant max: 0
    property variant total: 0
    property variant remaining: max - value
    property variant value: 0
    property int button_width: 140
    property int button_heigth: 40
    property int button_spacing: 15
    property int button_font_size: 12
    property alias grid_chips: grid
    property alias form: buyinForm
    property alias text_title: txtTitle
    property alias text_min: txtMin
    property alias text_value: txtValue
    property alias text_your_coins: txtYourCoins

    signal cancel()
    signal buyin(variant value)
    signal getChips()

    Rectangle {
        anchors.fill: parent
        color: myApp.getDebugMode() ? UtilsJs.random_color() : "black"
        opacity: 0.6
        MouseArea {
            anchors.fill: parent
        }
    }

    Rectangle {
        id: buyinForm
        width: 620
        height: 420
        color: "black"
        radius: 10
        anchors.centerIn: parent
        MouseArea {
            anchors.fill: parent
        }

        Image {
            id: btnClose
            height: 48
            width: height
            source: "../../images/Table/panel_close.png"
            anchors.right: parent.right
            anchors.top: parent.top
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.close();
                }
            }
        }

        Text {
            id: txtTitle
            color: "white"
            text: qsTr("BUY IN")
            anchors.top: parent.top
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.topMargin: 10
            font.pixelSize: 24
        }

        Text {
            id: txtYourCoins
            color: "white"
            anchors.top: txtTitle.bottom
            anchors.horizontalCenter: parent.horizontalCenter
            font.pixelSize: 20
            text: qsTr("Your Chips:") + root.total
        }

        Text {
            id: txtValue
            color: "white"
            text: root.value
            font.pixelSize: 22
            anchors.top: txtYourCoins.bottom
            anchors.topMargin: 10
            anchors.horizontalCenter: parent.horizontalCenter
        }

        Slider {
            id: sliderValue
            height: 40
            width: parent.width * 0.6
            anchors.top: txtValue.bottom
            anchors.topMargin: 10
            anchors.horizontalCenter: parent.horizontalCenter
            minimum: root.min
            maximum: root.max
//            stepSize: Math.floor((root.max - root.min) / 200)
            onValueChanged: {
                root.value = Math.floor(value);
            }
        }

        Text {
            id: txtMin
            color: "white"
            anchors.right: sliderValue.left
            anchors.rightMargin: 4
            anchors.verticalCenter: sliderValue.verticalCenter
            font.pixelSize: 20
            text: myApp.getFormattedNumber(root.min)
        }

        Text {
            id: txtMax
            color: "white"
            anchors.left: sliderValue.right
            anchors.leftMargin: 4
            anchors.verticalCenter: sliderValue.verticalCenter
            font.pixelSize: txtMin.font.pixelSize
            text: myApp.getFormattedNumber(root.max)
        }

        GridView {
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: sliderValue.bottom
            anchors.topMargin: 30
            id: grid
            width: 6 * cellWidth
            height: cellHeight * 2.5
            cellHeight: 80
            cellWidth: cellHeight
            clip: true
            model: ListModel {
                ListElement { img:"10M"; value: 10000000}
                ListElement { img: "100k"; value: 100000}
                ListElement { img: "10k"; value: 10000}
                ListElement {img: "2k"; value: 2000}
                ListElement { img: "500"; value: 500}
                ListElement { img: "50"; value: 50}

                ListElement { img: "1M"; value: 1000000}
                ListElement { img: "50k"; value: 50000}
                ListElement { img: "5k"; value: 5000}
                ListElement { img: "1k"; value: 1000}
                ListElement { img: "100"; value: 100}
                ListElement { img: "10"; value: 10}
            }
            delegate: Item {
                width: grid.cellHeight * 0.96
                height: width
                Image {
                    source: "../../images/Chip/" + img + ".png"
                    anchors.fill: parent
                    visible: root.remaining >= value
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            root.value += value;
                            if (root.value > root.max)
                                root.value = root.max;
                        }
                    }
                }
            }
        }


        Row {
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: root.button_spacing
            width: root.button_width * 4 + root.button_spacing * 3
            height: root.button_height

            Button {
                height: root.button_heigth
                width: root.button_width
                text: qsTr("Get Chips")
                font.pixelSize: root.button_font_size
                onClicked: {
                    root.getChips();
                    close();
                }
            }

            Button {
                height: root.button_heigth
                width: root.button_width
                text: root.value > root.min ? qsTr("Reset") : qsTr("Cancel")
                font.pixelSize: root.button_font_size
                onClicked: {
                    if (root.value > root.min) {
                        root.reset();
                    } else {
                        root.close();
                        root.cancel();
                    }
                }
            }

            Button {
                height: root.button_heigth
                width: root.button_width
                text: qsTr("All-In")
                font.pixelSize: root.button_font_size
                onClicked: {
                    close();
                    root.buyin(root.max);
                }
            }

            Button {
                height: root.button_heigth
                width: root.button_width
                text: qsTr("Play")
                font.pixelSize: root.button_font_size
                onClicked: {
                    close();
                    root.buyin(root.value);
                }
            }
        }

    }

    function show(min, max, total) {
        root.min = min;
        root.max = max;
        root.total = total;
        root.value = root.min;

        sliderValue.value = root.min;
        visible = true;
    }

    function close() {
        visible = false;
        root.cancel();
    }

    function reset() {
        root.value = min;
        sliderValue.value = root.value;
    }
}
