import QtQuick 1.1
import "../common"

Item {
    id: root
    width: 310
    height: 240
    property int seat_id: 0
    property int cell_width: 48
    property int cell_height: 50
    property int cell_text_font_size: 20
    property alias button_close: btnClose
    signal buyDrink(int seat, int drink)
    signal buyFood(int seat, int food)
    Rectangle {
        width: parent.width
        height: parent.height - btnClose.height + 6
        anchors.left: parent.left
        anchors.top: parent.top
        color: "black"
        radius: 10
        MouseArea {
            anchors.fill: parent
        }
        Rectangle {
            id: btnDrink
            width: 100
            height: 40
            anchors.left: parent.left
            anchors.top: parent.top
            property bool selected: true
            color: "darkgrey"
            property alias txt: txtDrink
            Text {
                id: txtDrink
                text: qsTr("Drink")
                anchors.centerIn: parent
                color: "black"
            }
            onSelectedChanged: {
                btnFood.selected = !selected;
                if (selected) {
                    btnDrink.color = "darkgrey";
                    btnDrink.txt.color = "black";
                } else {
                    btnDrink.color = "black";
                    btnDrink.txt.color = "darkgrey";
                }
            }
            MouseArea {
                anchors.fill: parent
                onPressed:  {
                    btnDrink.selected = !btnDrink.selected;
                }
            }
        }
        Rectangle {
            id: btnFood
            width: btnDrink.width
            height: btnDrink.height
            anchors.left: btnDrink.right
            anchors.leftMargin: 2
            anchors.top: btnDrink.top
            property bool selected: false
            color: "black"
            property alias txt: txtFood
            Text {
                id: txtFood
                text: qsTr("Food")
                anchors.centerIn: parent
                color: "darkgrey"
            }
            onSelectedChanged: {
                btnDrink.selected = !selected;
                if (selected) {
                    btnFood.color = "darkgrey";
                    btnFood.txt.color = "black";
                } else {
                    btnFood.color = "black";
                    btnFood.txt.color = "darkgrey";
                }
            }
            MouseArea {
                anchors.fill: parent
                onPressed: {
                    btnFood.selected = !btnFood.selected;
                }
            }
        }
        GridView {
            id: gridDrink
            width: parent.width
            height: parent.height - btnDrink.height
            anchors.top: btnDrink.bottom
            anchors.left: parent.left
            clip: true
            model: 15
            cellWidth: root.cell_width
            cellHeight: root.cell_height
            visible: btnDrink.selected

            delegate: Component {
                Item {
                    width: root.cell_width
                    height: root.cell_height
                    Image {
                        height: root.cell_height * 0.6
                        width: height
                        anchors.top: parent.top
                        anchors.horizontalCenter: parent.horizontalCenter
                        source: params.getDrinkImagePath(index+1)
                    }
                    Text {
                        width: parent.width
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.bottom: parent.bottom
                        anchors.bottomMargin: 10
                        text: params.getPriceByGiftDrinkId(index+1)
                        color: "white"
                        horizontalAlignment: Text.AlignHCenter
                        font.pixelSize: root.cell_text_font_size
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            gridDrink.currentIndex = index;
                            root.buyDrinkWithId(index+1);
                        }
                    }
                }
            }
            highlight: Rectangle {
                color: "darkslategray"
                //width: 50
                //height: width
                x: gridDrink.currentItem.x
                y: gridDrink.currentItem.y
                Behavior on x {
                    SpringAnimation {
                        spring: 3
                        damping: 0.2
                    }
                }
                Behavior on y {
                    SpringAnimation {
                        spring: 3
                        damping: 0.2
                    }
                }
            }
            Component.onCompleted: {
                gridDrink.currentIndex = 0;
            }
        }
        GridView {
            id: gridFood
            width: parent.width
            height: parent.height - btnDrink.height
            anchors.top: btnDrink.bottom
            anchors.left: parent.left
            clip: true
            model: 24
            cellWidth: root.cell_width
            cellHeight: root.cell_height
            visible: btnFood.selected

            delegate: Component {
                Item {
                    width: gridFood.cellWidth
                    height: gridFood.cellHeight
                    Image {
                        height: root.cell_height * 0.6
                        width: height
                        anchors.top: parent.top
                        anchors.horizontalCenter: parent.horizontalCenter
                        source: params.getFoodImagePath(index+1)
                    }
                    Text {
                        width: parent.width
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.bottom: parent.bottom
                        anchors.bottomMargin: 10
                        text: params.getPriceByGiftFoodId(index+1)
                        color: "white"
                        horizontalAlignment: Text.AlignHCenter
                        font.pixelSize: root.cell_text_font_size
                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            gridFood.currentIndex = index;
                            root.buyFoodWithId(index+1);
                        }
                    }
                }
            }
            highlight: Rectangle {
                color: "darkslategray"
                // width: 50
                // height: width
                x: gridFood.currentItem.x
                y: gridFood.currentItem.y
                Behavior on x {
                    SpringAnimation {
                        spring: 3
                        damping: 0.2
                    }
                }
                Behavior on y {
                    SpringAnimation {
                        spring: 3
                        damping: 0.2
                    }
                }
            }
            Component.onCompleted: {
                gridFood.currentIndex = 0;
            }
        }

    }


    Rectangle {
        id: btnClose
        height: 40
        width: height
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        color: "black"
        radius: 6
        Text {
            text: "x"
            anchors.centerIn: parent
            font.pixelSize: parent.height * 0.8
            color: "white"
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                root.hide();
            }
        }
    }

    function show(seat) {
        seat_id = seat;
        visible = true;
    }

    function hide() {
        seat_id = 0;
        visible = false;
    }

    function buyFoodWithId(i) {
        root.buyFood(seat_id, i);
    }
    function buyDrinkWithId(i) {
        root.buyDrink(seat_id, i);
    }
}
