import QtQuick 1.1
import "../../scripts/utils.js" as UtilsJs

Rectangle {
    id: root
    width: 80
    height: 48

    border.width: 2
    radius: 6
    border.color: "lightgray"
    color: myApp.getDebugMode() ? UtilsJs.random_color() : "black"

    property bool sound_enable: true
    property bool vibra_enable: true
    property alias rect_menu: rectMenu
    property int menu_column_height: 40
    property int menu_item_font_size: 20
    property alias text_menu: txtMenu

    signal leaveGame()
    signal soundOnOff(bool on)
    signal vibraOnOff(bool on)

    //menu icon
    Text {
        id: txtMenu
        text: qsTr("MENU")
        color: "white"
        font.pixelSize: 20
        anchors.centerIn: parent
    }
    MouseArea {
        anchors.fill: parent
        onPressed: {
            console.log("slide up menu");
            rectMenu.state = "on";
        }
    }

    //block chat
    //block animated avatar

    Rectangle {
        id: rectMenu
        width: 100
        height: menuCol.height + menuCol.anchors.topMargin +  border.width
        color: "black"
        y: -height
        x: -20
        border.width: 2
        border.color: "lightgrey"
        states: [
            State {
                name: "on"
                PropertyChanges {
                    target: rectMenu
                    y: 0
                }
            },
            State {
                name: "off"
                PropertyChanges {
                    target: rectMenu
                    y: -rectMenu.height
                }
            }

        ]
        state: "off"
        MouseArea {
            anchors.fill: parent
            onPressed: {
                rectMenu.state = "off";
            }
        }

        Column {
            id: menuCol
            width: parent.width - parent.border.width * 2
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 10
            Rectangle {
                width: parent.width
                height: root.menu_column_height
                color: "black"
                Text {
                    text: qsTr("resume")
                    color: "white"
                    font.pixelSize: root.menu_item_font_size
                    anchors.centerIn: parent
                }
                MouseArea {
                    anchors.fill: parent
                    onPressed: {
                        root.menuOff();
                    }
                }
            }
            Rectangle {
                width: parent.width
                height: root.menu_column_height
                color: "black"
                anchors.horizontalCenter: parent.horizontalCenter
                Text {
                    text: qsTr("leave game")
                    color: "white"
                    font.pixelSize: root.menu_item_font_size
                    anchors.centerIn: parent
                }
                MouseArea {
                    anchors.fill: parent
                    onPressed: {
                        root.menuOff();
                        root.leaveGame();
                    }
                }
            }
            Rectangle {
                width: parent.width
                height: root.menu_column_height
                color: "black"
                anchors.horizontalCenter: parent.horizontalCenter
                Text {
                    text: root.sound_enable ? qsTr("sound off") : qsTr("sound on")
                    color: "white"
                    font.pixelSize: root.menu_item_font_size
                    anchors.centerIn: parent
                }
                MouseArea {
                    anchors.fill: parent
                    onPressed: {
                        root.sound_enable = !root.sound_enable;
                        root.menuOff();
                        root.soundOnOff(root.sound_enable);
                    }
                }
            }
            Rectangle {
                width: parent.width
                height: root.menu_column_height
                color: "black"
                anchors.horizontalCenter: parent.horizontalCenter
                Text {
                    text: root.vibra_enable ? qsTr("vibra off") : qsTr("vibra on")
                    color: "white"
                    font.pixelSize: root.menu_item_font_size
                    anchors.centerIn: parent
                }
                MouseArea {
                    anchors.fill: parent
                    onPressed: {
                        root.vibra_enable = !root.vibra_enable;
                        root.menuOff();
                        root.vibraOnOff(root.vibra_enable);
                    }
                }

            }
        }

    }
    function menuOn() {
        rectMenu.state = "on";
    }

    function menuOff() {
        rectMenu.state = "off";
    }
}
