import QtQuick 1.1
import com.prevantage.holdem.components 1.0
import "../common"
import "../../scripts/utils.js" as UtilsJs
import "../../scripts/seat.js" as SeatJs

Item {
    id: root
    width: 130
    height: 100
    property int bottom_margin_5: 0
    property int bottom_margin_9: 0
    property int left_margin_5: 0
    property int left_margin_9: 0
    property int top_margin_5: 0
    property int top_margin_9: 0
    property int right_margin_5: 0
    property int right_margin_9: 0
    property int remote_id: 0
    property int position: 0
    property alias image_avatar: imgAvatar
    property string name: ""
    property int action: params.getSaNone()
    property alias bar_chips: chipsBar
    property int bar_chips_font_size: 14
    property alias bar_title: titleBar
    property alias bar_title_name: titleBar.text_front
    property alias bar_title_action: titleBar.text_back
    property int label_bet_x_5: 0
    property int label_bet_y_5: 0
    property int label_bet_x_9: 0
    property int label_bet_y_9: 0
    property int label_bet_font_size: 14
    property int chatballoon_x_5;
    property int chatballoon_y_5;
    property int chatballoon_x_9;
    property int chatballoon_y_9;
    property int chat_balloon_font_size: 14

    property int icon_dealer_height: 48
    property int button_sitdown_height: 48

    property alias label_bet: lblBet
    property alias chat_balloon: chatBalloon
    property alias icon_sb: imgSmallBlind
    property alias icon_bb: imgBigBlind
    property alias icon_dealer: imgDealer
    property alias icon_cardbacks: imgCardBacks
    property alias card_1: card1
    property alias card_2: card2
    property alias button_sitdown: btnSitdown
    property int gift_x: 0
    property int gift_y: 0
    property string gift_src: ""
    property alias icon_gift: imgGift

    Component.onCompleted:  {
    }

    onGift_srcChanged:  {
        giftAnimation.stop();
        if (gift_src !== "") {
            giftAnimation.start();
        }
    }

    signal showInfo()

    onActionChanged: {
        var s = "";
        switch (action) {
        case params.getSaAllIn():
            s = qsTr("All-In");
            break;
        case params.getSaBet():
            s = qsTr("Bet");
            break;
        case params.getSaCall():
            s = qsTr("Call");
            break;
        case params.getSaCheck():
            s = qsTr("Check");
            break;
        case params.getSaFold():
            s = qsTr("Fold");
            break;
        case params.getSaRaise():
            s = qsTr("Raise");
            break;
        case params.getSaWaitForNextHand():
            s = qsTr("WaitFNH");
            break;
        }
        titleBar.text_back.text = s;
    }
    onNameChanged: {
        titleBar.text_front.text = name;
    }

    SeatProgressBar {
        id: spb
        duration: params.getTimeoutForSeatAction()
        anchors.fill: parent
    }

    Rectangle {
        id: frontLayer
        anchors.fill: parent
        anchors.margins: 2
        color: "black"
        radius: 6
        visible: false
        MouseArea {
            anchors.fill: parent
            onClicked: {
                root.showInfo();
            }
            onPressAndHold: {
                myApp.tableUsrDidShowHandWithSeat(remote_id);
            }
        }

        AnimatedImage {
            id: imgAvatar
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            visible: source != ""
            asynchronous: true
        }

        Image {
            id: imgSmallBlind
            height: 20
            width: height
            x: imgDealer.x
            y: imgDealer.height
            source: "../../images/Table/smallblind.png"
            visible: false
        }

        Image {
            id: imgBigBlind
            height:20
            width: height
            x: imgSmallBlind.x
            y: imgSmallBlind.y
            source: "../../images/Table/bigblind.png"
            visible: false
        }

        Image {
            id: imgDealer
            height: 20
            width: height
            source: "../../images/Table/dealer.png"
            visible: false
        }

        PropertyAnimation {
            id: giftAnimation
            target: root
            property: "gift_src"
            to: ""
            duration: 180000
            running: false
        }

        SeatTitleBar {
            id: titleBar
            width: parent.width
            height: 20
            anchors.top: parent.top
            anchors.left: parent.left
        }

        Image {
            id: imgCardBacks
            source: "../../images/Card/backs.png"
            width: height
            anchors.right: parent.right
            anchors.rightMargin: 6
            anchors.bottom: chipsBar.top
            visible: false
        }

        Image {
            id: imgGift
            height: 48
            width: height
            source: root.gift_src
            visible: root.gift_src !== ""
            anchors.verticalCenter: parent.verticalCenter
        }

        Card {
            id: card1
            visible: false
            anchors.bottom: chipsBar.top
            anchors.right: card2.left
        }

        Card {
            id: card2
            visible: card1.visible
            width: card1.width
            height: card1.height
            anchors.bottom: card1.bottom
            anchors.right: parent.right
        }

        SeatChipsBar {
            id: chipsBar
            text_chips.font.pixelSize: root.bar_chips_font_size
            width: parent.width
            height: 20
            anchors.bottom: parent.bottom
            anchors.left: parent.left
        }
    }


    SeatBetBar {
        id: lblBet
        text.font.pixelSize: root.label_bet_font_size
    }

    Text {
        text: remote_id
        color: "red"
        anchors.top: parent.top
        anchors.left: parent.left
        verticalAlignment: Text.AlignTop
        visible: myApp.getDebugMode()
    }

    ChatBalloon {
        id: chatBalloon
        visible: false
        font_size: chat_balloon_font_size
    }

    Image {
        id: btnSitdown
        visible: false
        height: button_sitdown_height
        width: height
        property bool isPressed: false
        source: btnSitdown.isPressed === true ? "../../images/Table/sit_highlighted.png" : "../../images/Table/sit_normal.png"
        anchors.centerIn: parent
        MouseArea {
            anchors.fill: parent
            onPressed: {
                btnSitdown.isPressed = true;
            }
            onReleased: {
                btnSitdown.isPressed = false;
            }
            onClicked: {
                root.sitButton(false);
                myTable.usrDidSitWithSeat(remote_id);
            }
        }
    }

    function resetPosition(t) {
        if (myTable.getSize() === params.getTableSize5()) {
            switch (position) {
            case 1:
                anchors.horizontalCenter = parent.horizontalCenter;
                anchors.bottom = parent.bottom;
                if (root.bottom_margin_5 > 0) {
                    anchors.bottomMargin = root.bottom_margin_5;
                }
                imgDealer.x = - imgDealer.width;
                break;
            case 2:
                anchors.left = parent.left;
                anchors.bottom = parent.bottom;
                if (root.bottom_margin_5 > 0) {
                    anchors.bottomMargin = root.bottom_margin_5;
                }
                imgDealer.x = root.width;
                break;
            case 3:
                anchors.top = parent.top;
                anchors.right = parent.horizontalCenter;
                if (root.right_margin_5 > 0) {
                    anchors.rightMargin = root.right_margin_5;
                }
                imgDealer.x = root.width;
                break;
            case 4:
                anchors.top = parent.top;
                anchors.left = parent.horizontalCenter;
                if (root.left_margin_5 > 0) {
                    anchors.leftMargin = root.left_margin_5;
                }
                imgDealer.x = -imgDealer.width;
                break;
            case 5:
                anchors.right = parent.right;
                anchors.bottom = parent.bottom;
                if (root.bottom_margin_5 > 0) {
                    anchors.bottomMargin = root.bottom_margin_5;
                }
                imgDealer.x = -imgDealer.width;
                break;
            }
            lblBet.x = root.label_bet_x_5;
            lblBet.y = root.label_bet_y_5;
            chatBalloon.x = root.chatballoon_x_5;
            chatBalloon.y = root.chatballoon_y_5;
        } else {
            switch (position) {
            case 1:
                anchors.horizontalCenter = parent.horizontalCenter;
                anchors.bottom = parent.bottom;
                if (root.bottom_margin_9 > 0) {
                    anchors.bottomMargin = root.bottom_margin_9;
                }
                imgDealer.x = - imgDealer.width;
                break;
            case 2:
                anchors.left = parent.left;
                anchors.bottom = parent.bottom;
                if (root.bottom_margin_9 > 0) {
                    anchors.bottomMargin = root.bottom_margin_9;
                }
                imgDealer.x = root.width;
                break;
            case 3:
                anchors.left = parent.left;
                anchors.top = parent.top;
                if (root.top_margin_9 > 0) {
                    anchors.topMargin = root.top_margin_9;
                }
                imgDealer.x = root.width;
                break;
            case 4:
                anchors.top = parent.top;
                anchors.left = parent.left;
                if (root.left_margin_9 > 0) {
                    anchors.leftMargin = root.left_margin_9;
                }
                if (root.top_margin_9 > 0) {
                    anchors.topMargin = root.top_margin_9;
                }
                imgDealer.x = root.width;
                break;
            case 5:
                anchors.top = parent.top;
                anchors.right = parent.horizontalCenter;
                if (root.right_margin_9 > 0) {
                    anchors.rightMargin = root.right_margin_9;
                }
                imgDealer.x = root.width;
                break;
            case 6:
                anchors.top = parent.top;
                anchors.left = parent.horizontalCenter;
                if (root.left_margin_9 > 0) {
                    anchors.leftMargin = root.left_margin_9;
                }
                imgDealer.x = -imgDealer.width;
                break;
            case 7:
                anchors.top = parent.top;
                anchors.right = parent.right;
                if (root.right_margin_9 > 0) {
                    anchors.rightMargin = root.right_margin_9;
                }
                if (root.top_margin_9 > 0) {
                    anchors.topMargin = root.top_margin_9;
                }
                imgDealer.x = -imgDealer.width;
                break;
            case 8:
                anchors.top = parent.top;
                anchors.right = parent.right;
                if (root.top_margin_9 > 0) {
                    anchors.topMargin = root.top_margin_9;
                }
                imgDealer.x = -imgDealer.width;
                break;
            case 9:
                anchors.bottom = parent.bottom;
                anchors.right = parent.right;
                if (root.bottom_margin_9 > 0) {
                    anchors.bottomMargin = root.bottom_margin_9;
                }
                imgDealer.x = -imgDealer.width;
                break;
            }
            lblBet.x = root.label_bet_x_9;
            lblBet.y = root.label_bet_y_9;
            chatBalloon.x = root.chatballoon_x_9;
            chatBalloon.y = root.chatballoon_y_9;
        }
        if (position === 1) {
            imgGift.anchors.left = frontLayer.left;
        } else {
            imgGift.anchors.right = frontLayer.right;
        }

        root.gift_y = root.y + imgGift.y;
        root.gift_x = root.x + imgGift.x;
    }

    function setInfo(uuid, a_action, a_chips, a_bet) {
        btnSitdown.visible = false;
        frontLayer.visible = true;
        name = qsTr("Guest");
        imgAvatar.visible = false;
        imgAvatar.source = "";
        if (!myApp.getOfflineMode()) {
            if (myApp.tableIsAvatarMyself(uuid)) {
                name = myApp.settingsGetNickName();
                imgAvatar.source = myApp.settingsGetAvatarUrl();
                imgAvatar.visible = true;
            } else {
                SeatJs.getProfile(remote_id, uuid);
            }
        }

        action = a_action;
        chipsBar.chips = a_chips;
        lblBet.value = a_bet;
    }

    function didBuyChips(c) {
        if (!frontLayer.visible)
            return;
        chipsBar.chips += c;
    }

    function didSmallBlind(i) {
        if (i > 0) {
            chipsBar.chips -= i;
            lblBet.value = i;
            titleBar.text_back.text = qsTr("S Blind");
        }
        action = params.getSaBet();
        showSmallBlindButton();
    }
    function didBigBlind(i) {
        if (i > 0) {
            chipsBar.chips -= i;
            lblBet.value = i;
            titleBar.text_back.text = qsTr("B Blind");
        }
        action = params.getSaBet();
        showBigBlindButton();
    }

    function showSmallBlindButton() {
        imgSmallBlind.visible = true;
    }
    function showBigBlindButton() {
        imgBigBlind.visible = true;
    }
    function showDealerButton() {
        imgDealer.visible = true;
    }

    function didLeave() {
        chipsBar.chips = 0;
        name = "";
        action = params.getSaNone();
        gift_src = "";
        chipsBar.chips = 0;
        lblBet.value = 0;
        handClean();
        imgAvatar.source = "";
        frontLayer.visible = false;
    }

    function handClean() {
        if (!frontLayer.visible)
            return;
        if (btnSitdown.visible)
            return;
        spb.stop();
        titleBar.text_back.text = "";
        action = params.getSaNone();
        lblBet.value = 0;
        card1.hide();
        card2.hide();
        imgCardBacks.visible = false;
        imgSmallBlind.visible = false;
        imgBigBlind.visible = false;
        imgDealer.visible = false;
    }

    function resetForNewRound(clearAction) {
        lblBet.value = 0;
        if (clearAction) {
            action = params.getSaNone();
        }
    }

    function timer(start) {
        if (start) {
            action = params.getSaNone();
            spb.start();
        } else {
            spb.stop();
        }
    }

    function sitButton(show) {
        btnSitdown.visible = show;
    }

    function didSpendChips(c) {
        if (!frontLayer.visible)
            return;
        chipsBar.chips -= c;
    }
    function didWin(c) {
        titleBar.text_back.text = "+" + myApp.getFormattedNumber(c);
        chipsBar.chips += c;
    }
    function didCall(c) {
        timer(false);
        action = params.getSaCall();
        chipsBar.chips -= c;
        lblBet.value += c;
    }
    function didCheck() {
        timer(false);
        action = params.getSaCheck();
    }
    function didAllIn() {
        timer(false);
        action = params.getSaAllIn();
        lblBet.value += chipsBar.chips;
        chipsBar.chips = 0;
    }
    function didBet(c) {
        timer(false);
        action = params.getSaBet();
        chipsBar.chips -= c;
        lblBet.value = c;
    }
    function didRaise(call, add) {
        timer(false);
        action = params.getSaRaise();
        var value = call - lblBet.value + add;
        chipsBar.chips -= value;
        lblBet.value += value;
    }
    function preflopWithCards(id1, id2) {
        if (!frontLayer.visible)
            return;
        if (action === params.getSaWaitForNextHand())
            return;
        if (id1 === params.getINVALID_CARD() || id2 === params.getINVALID_CARD()) {
            imgCardBacks.visible = true;
        } else {
            imgCardBacks.visible = false;
            card1.card_id = id1;
            card2.card_id = id2;
        }
    }
    function didFold() {
        timer(false);
        action = params.getSaFold();
    }

    function darkCards() {
        card1.be_dark();
        card2.be_dark();
    }

    function highlightCard(id) {
        card1.highlight_by_id(id);
        card2.highlight_by_id(id);
    }
    function showHand(id1, id2) {
        imgCardBacks.visible = false;
        card1.card_id = id1;
        card2.card_id = id2;
    }
    function didChat(s) {
        chatBalloon.show(s);
    }

    function loadProfile(s) {
        if (!frontLayer.visible)
            return;
        var data = JSON.parse(s);
        root.name = data.name;
        if (remote_id === myTable.getHumanSeatId() && !myTable.isVisitorMode()) {
            myApp.settingsSaveNickname(data.name);
        }
        switch (data.avatar_type) {
        case 0:
            imgAvatar.source = myApp.getAvatarImagePath(data.avatar_url);
            break;
        case 1:
            imgAvatar.source = "http://holdem2.piegames.net/profile.php?v=1.0&action=image&uuid=" + data.avatar_url;
            if (remote_id === myTable.getHumanSeatId() && !myTable.isVisitorMode()) {
                myApp.settingsSaveAvatar(1, imgAvatar.source);
            }
            break;
        }
        imgAvatar.visible = true;

    }
}
