import QtQuick 1.1
import "../common"

Item {
    id: root
    width: 180
    height: 200
    property int chips: 0
    property alias button_close: btnClose
    property alias label_close: lblClose
    property alias image_avatar: imgAvatar
    property alias text_name: txtName
    property alias button_buddy: btnBuddy
    property alias button_sendgift: btnSendGift
    property alias button_sendchips: btnSendChips
    property alias button_chatblock: btnChatBlock
    property int seat_id: 0
    signal sendChips(int i)
    signal sendGift(int i)
    signal closed()

    Connections {
        target: myTable
        onTableBuddyStatusBySeat: {
            console.log("seatid=" + seatid + " status=" + status);
            if (root.seat_id !== seatid)
                return;
            btnBuddy.show(status);
        }
    }

    Rectangle {
        width: parent.width
        height: parent.height - btnClose.height + 10
        anchors.left: parent.left
        anchors.top: parent.top
        color: "black"
        radius: 10
        MouseArea {
            anchors.fill: parent
            onClicked: {
                root.hide();
            }
        }
        Image {
            id: imgAvatar
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.top: parent.top
            anchors.topMargin: 10
            height: 64
            width: height
        }

        BuddyButton {
            id: btnBuddy
            anchors.verticalCenter: imgAvatar.verticalCenter
            anchors.left: imgAvatar.right
            anchors.leftMargin: 4
            visible: true
            onClicked: {
                visible = false;
                myApp.tableUsrBuddyRequest(root.seat_id);
            }
        }

        Text {
            id: txtName
            color: "white"
            font.pixelSize: 14
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: imgAvatar.bottom
            anchors.topMargin: 4
            width: parent.width - 10
            elide: Text.ElideRight
            maximumLineCount: 1
            horizontalAlignment: Text.AlignHCenter
        }

        Image {
            id: btnSendGift
            width: 48
            height: width
            anchors.left: parent.left
            anchors.leftMargin: 4
            anchors.top: txtName.bottom
            anchors.topMargin: 10
            source: myTable.isVisitorMode() ? "../../images/Table/gift_bw.png" : "../../images/Table/gift.png";
            visible: true
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.sendGift(root.seat_id);
                }
            }
        }

        Image {
            id: btnSendChips
            source: "../../images/Gift/chips.png"
            width: btnSendGift.width
            height: width
            anchors.left: btnSendGift.right
            anchors.leftMargin: 6
            anchors.top: btnSendGift.top
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.sendChips(root.seat_id);
                }
            }
        }
        Image {
            id: btnChatBlock
            width: btnSendGift.width
            height: width
            anchors.left: btnSendChips.right
            anchors.leftMargin: 6
            anchors.top: btnSendGift.top
            source: myTable.isChatBlock(root.seat_id) ? "../../images/Table/chat_locked.png" : "../../images/Table/chat_unlocked.png"
            visible: !myTable.isVisitorMode()
            MouseArea {
                anchors.fill: parent
                onClicked: {
                    myTable.toggleChatBlock(root.seat_id);
                    btnChatBlock.source = myTable.isChatBlock(root.seat_id) ? "../../images/Table/chat_locked.png" : "../../images/Table/chat_unlocked.png";
                }

            }
        }

        //sendgift
        //sendchips
        //chatlock


    }
    Rectangle {
        id: btnClose
        height: 40
        width: height
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.leftMargin: 10
        radius: 6
        color: "black"
        Text {
            id: lblClose
            text: qsTr("x")
            anchors.centerIn: parent
            font.pixelSize: parent.height * 0.6
            font.bold: true
            color: "white"
        }
        MouseArea {
            anchors.fill: parent
            onClicked:  {
                root.hide();
            }
        }
    }

    function show(seat) {
        hide();
        seat_id = seat.remote_id;
        imgAvatar.source = seat.image_avatar.source;
        txtName.text = seat.name;

        myApp.tableUsrBuddyStatus(seat_id);
        btnSendChips.visible = !myTable.isVisitorMode();
        btnSendGift.visible = !myTable.isVisitorMode();
        btnSendGift.source = myTable.isVisitorMode() ? "../../images/Table/gift_bw.png" : "../../images/Table/gift.png";
        btnChatBlock.visible = !myTable.isVisitorMode();
        btnBuddy.visible = !myTable.isVisitorMode();
        visible = true;
    }
    function hide() {
        root.closed();
        visible = false;
    }
}
