import QtQuick 1.1
import "../common"
import "../../scripts/utils.js" as UtilsJs

Item {
    id: root
    width: 400
    height: 250
    property int seat_id: 0
    property int max_value: 0
    property int current_value: 0
    property alias text_value: txtValue
    property alias text_dailylimit: txtDailyLimit
    property alias button_send: btnSend
    property alias row_chips: rowChips
    onCurrent_valueChanged: {
        if (current_value > max_value) {
            current_value = max_value;
        }
    }

    signal send(int seat, int chips);
    Rectangle {
        width: parent.width
        height: parent.height - btnClose.height + 6
        anchors.left: parent.left
        anchors.top: parent.top
        color: "black"
        radius: 10
        MouseArea {
            anchors.fill: parent
        }

        Rectangle {
            id: rectValue
            width: parent.width * 0.6
            height: txtValue.height
            anchors.horizontalCenter: parent.horizontalCenter
            radius: 8
            color: "darkgrey"
            Text {
                id: txtValue
                text: root.current_value
                color: "black"
                font.pixelSize: 34
                font.bold: true
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
            }
        }
        Rectangle {
            visible: myApp.getDebugMode()
            width: rowChips.width
            height: rowChips.height
            color: UtilsJs.random_color()
            anchors.left: rowChips.left
            anchors.bottom: rowChips.bottom
        }

        Row {
            id: rowChips
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: rectValue.bottom
            anchors.topMargin: 10
            spacing: 10
            height: 48
            Image {
                height: parent.height
                width: height
                source: "../../images/Chip/100.png"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        root.current_value += 100;
                    }
                }
            }
            Image {
                height: parent.height
                width: height
                source: "../../images/Chip/1k.png"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        root.current_value += 1000;
                    }
                }
            }
            Image {
                height: parent.height
                width: height
                source: "../../images/Chip/10k.png"
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        root.current_value += 10000;
                    }
                }
            }
        }
        Text {
            id: txtDailyLimit
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 10
            font.pixelSize: 20
            color: "white"
            horizontalAlignment: Text.AlignHCenter
            width: parent.width
            text: "Today Remaining: " + max_value
            verticalAlignment: Text.AlignTop
        }
    }

    Rectangle {
        id: btnSend
        height: 40
        width: height
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        color: "black"
        Image {
            id: imgSend
            source: "../../images/Table/btn_okey.png"
            anchors.centerIn: parent
        }
        MouseArea {
            anchors.fill: parent
            onClicked:  {
                root.send(seat_id, current_value);
                root.hide();
            }
        }
    }

    Rectangle {
        id: btnClose
        height: btnSend.height
        width: height
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        color: "black"
        Text {
            text: "x"
            anchors.centerIn: parent
            font.bold: true
            font.pixelSize: parent.height * 0.8
            color: "white"
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                root.hide();
            }
        }
    }

    function show(seat, limit) {
        root.seat_id = seat;
        root.max_value = limit;
        visible = true;
    }

    function hide() {
        seat_id = 0;
        max_value = 0;
        current_value = 0;
        visible = false;
    }
}
