import QtQuick 1.1
import "../common"
import "../../scripts/utils.js" as UtilsJs

Item {
    id: root
    anchors.fill: parent

    property alias button_test: btnTest
    property int table_size: params.getTableSize5()

    property int seat_1_label_bet_x_5: 30
    property int seat_1_label_bet_y_5: -30
    property int seat_1_label_bet_x_9: 30
    property int seat_1_label_bet_y_9: -30

    property alias seat_1: seat1
    property alias seat_2: seat2
    property alias seat_3: seat3
    property alias seat_4: seat4
    property alias seat_5: seat5
    property alias seat_6: seat6
    property alias seat_7: seat7
    property alias seat_8: seat8
    property alias seat_9: seat9
    property int seat_width: 130
    property int seat_height: 80
    property int seat_bar_chips_height: 14
    property int seat_bar_chips_font_size: 14
    property int seat_bar_title_height: 16
    property int seat_bar_title_name_font_size: 14
    property int seat_bar_title_action_font_size: 14
    property alias label_tax: lblTax
    property alias label_mainpot: lblMainPot
    property alias label_call: lblCall
    property alias deck: deck
    property alias bar_tip: tip
    property int seat_label_bet_width: 50
    property int seat_label_bet_height: 20
    property int seat_label_bet_font_size: 14
    property int seat_card_height: 60
    property int seat_avatar_width: 64
    property int seat_avatar_height: 64
    property int seat_icon_cardsback_height: 35
    property int seat_icon_dealer_height: 48
    property int seat_gift_height: 48
    property int seat_button_sitdown_height: 80
    property alias action_bar: actionBar
    property alias button_chat: btnChat
    property alias dialog_waitforothers: dlgWaitForOthers
    property alias dialog_waitfornexthand: dlgWaitForNextHand
    property alias dialog_chat: dlgChat
    property alias dialog_seatinfo: dlgSeatInfo
    property alias dialog_sendchips: dlgSendChips
    property alias dialog_giftstore: dlgGiftStore
    property alias dialog_bet: dlgBet
    property alias dialog_quit: dlgQuit
    property alias dialog_dailybonus: dlgDailyBonus
    property alias dialog_noenoughchips: dlgNoEnoughChips
    property alias dialog_servernoservice: dlgServerNoService
    property alias dialog_disconnectedfromgamed: dlgGamedDisconnect
    property alias dialog_buyin: dlgBuyIn
    property alias menu: menu

    property int seat_chatballoon_width: 160
    property int seat_chatballoon_height: 60
    property int seat_chatballoon_font_size: 14

    Connections {
        target: myTable
        onTablePreflopWithCards: {
            for (var i = 1; i <= myTable.getSize(); i++) {
                var seat = seatByRemoteId(i);
                if (seat.remoteId === myTable.getHumanSeatId() && !myTable.isVisitorMode()) {
                    seat.preflopWithCards(id1, id2);
                } else {
                    seat.preflopWithCards(params.getINVALID_CARD(), params.getINVALID_CARD());
                }
            }
        }
        onTablePreflopWithSeatAndCards: {
            seatByRemoteId(seatid).preflopWithCards(id1, id2);
        }

        onTableFlopWithCards: {
            deck.flop(card1, card2, card3);
            tip.show(qsTr("Flop"), 1.5);
        }
        onTableTurnWithCard: {
            deck.turn(card);
            tip.show(qsTr("Turn"), 1.5);
        }
        onTableRiverWithCard: {
            deck.river(card);
            tip.show(qsTr("River"), 1.5);
        }
        onTableHandClean: {
            handclean();
        }
        onTableJoinWithSeat: {
            setSize(table_size);
            lblTax.text = qsTr("Service Chage applied to the Winner: ") + tax + "%";
            joinWithSeat(seat_id);
        }
        onTableSetInfoWithSeat: {
            var a_seat = seatByRemoteId(seat);
            if (a_seat !== null) {
                a_seat.setInfo(uuid, action, chips, bet);
            }
        }
        onTableBuyChipsWithSeat: {
            seatByRemoteId(seatid).didBuyChips(chips);
        }
        onTableDailyBonus: {
            dlgDailyBonus.show(c);
        }
        onTableShowActionBar: {
            actionBar.show(check, call, bet, raise);
        }
        onTableHideActionBar: {
            actionBar.hide();
        }
        onTableWaitForOthersDialog: {
            dlgWaitForOthers.visible = show;
        }
        onTableWaitForNextHandDialog: {
            dlgWaitForNextHand.visible = show;
        }
        onTableSmallBlindWithSeat: {
            seatByRemoteId(seatid).didSmallBlind(c);
        }
        onTableBigBlindWithSeat: {
            seatByRemoteId(seatid).didBigBlind(c);
        }
        onTableDealerWithSeat: {
            seatByRemoteId(seatid).showDealerButton();
        }
        onTableTimerWithSeat: {
            seatByRemoteId(seatid).timer(start);
        }
        onTableSitButtonWithSeat: {
            seatByRemoteId(seatid).sitButton(show);
        }
        onTableResetForNewRound: {
            seatByRemoteId(seatid).resetForNewRound(clearAction);
        }
        onTableHighlightCard: {
            deck.highlight(card);
            seatByRemoteId(seatid).highlightCard(card);
        }
        onTableDarkAllCards: {
            deck.darkCards();
            seatByRemoteId(seatid).darkCards();
        }
        onTableWinWithSeat: {
            seatByRemoteId(seatid).didWin(c);
            if (handtypename !== "") {
                tip.show(handtypename, params.getTimeoutForSeatWin());
            }
        }
        onTableNoEnoughChipsDialog: {
            dlgNoEnoughChips.visible = show;
        }
        onTestSeatWin: {
            seatByRemoteId(seat).didWin(chips);
        }
        onTableBetDialogShow: {
            dlgBet.show(min, max);
        }
        onTableAllInWithSeat: {
            seatByRemoteId(seatid).didAllIn();
        }
        onTableBetWithSeat: {
            seatByRemoteId(seatid).didBet(c);
        }
        onTableRaiseWithSeat: {
            seatByRemoteId(seatid).didRaise(c, a);
        }
        onTableCheckWithSeat: {
            seatByRemoteId(seatid).didCheck();
        }
        onTableFoldWithSeat: {
            seatByRemoteId(seatid).didFold();
        }
        onTableSetDeck: {
            deck.show(id1, id2, id3, id4, id5);
        }
        onTableQuitDialog: {
            if (show) {
                dlgQuit.open(qsTr("Confirmation"), qsTr("Quit") + "?");
            } else {
                dlgQuit.close();
            }
        }
        onTableShowPrivateCardsWithSeat: {
            seatByRemoteId(seatid).showHand(id1, id2);
        }

        onTableSendChipsFromAtoB: {
            var iconComponent = Qt.createComponent("AnimateGift.qml");
            if (iconComponent.status === Component.Ready) {

                var icon = iconComponent.createObject(root);
                icon.height = root.seat_gift_height;

                icon.ended.connect(root.sendChipsDone);
                var f_seat = seatByRemoteId(from_seat);
                f_seat.didSpendChips(chips);
                var t_seat = seatByRemoteId(to_seat);
                icon.start(f_seat.gift_x, f_seat.gift_y, t_seat.gift_x, t_seat.gift_y, params.getChipsImagePath(chips), to_seat, chips);
            }

        }
        onTableBuyFoodFromAtoB: {
            var iconComponent = Qt.createComponent("AnimateGift.qml");
            if (iconComponent.status === Component.Ready) {
                var icon = iconComponent.createObject(root);
                icon.height = root.seat_gift_height;

                icon.ended.connect(root.sendGiftFoodDone);
                var f_seat = seatByRemoteId(from_seat);
                f_seat.didSpendChips(params.getPriceByGiftFoodId(food));
                var t_seat = seatByRemoteId(to_seat);
                icon.start(f_seat.gift_x, f_seat.gift_y, t_seat.gift_x, t_seat.gift_y, params.getFoodImagePath(food), to_seat, food);
            }
        }
        onTableBuyDrinkFromAtoB: {
            var iconComponent = Qt.createComponent("AnimateGift.qml");
            if (iconComponent.status === Component.Ready) {
                var icon = iconComponent.createObject(root);
                icon.height = root.seat_gift_height;

                icon.ended.connect(root.sendGiftDrinkDone);
                var f_seat = seatByRemoteId(from_seat);
                f_seat.didSpendChips(params.getPriceByGiftDrinkId(drink));
                var t_seat = seatByRemoteId(to_seat);
                icon.start(f_seat.gift_x, f_seat.gift_y, t_seat.gift_x, t_seat.gift_y, params.getDrinkImagePath(drink), to_seat, drink);
            }
        }
        onTableUpdateMainPot: {
            updateMainPot(c);
        }
        onTableUpdateCall: {
            updateCall(c);
        }
        onTableCallWithSeat: {
            seatByRemoteId(seatid).didCall(c);
        }
        onTableLeaveWithSeat: {
            seatByRemoteId(seatid).didLeave();
        }
        onTableChatButton: {
            btnChat.visible = show;
        }
        onTableChatWithSeat: {
            seatByRemoteId(seatid).didChat(s);
        }
        onTableGamedNoService: {
            dlgServerNoService.open();
        }
        onTableSoundPlay: {
            soundPlay(i);
        }
        onTableBuyInWith: {
            if (!dlgDailyBonus.visible)
                dlgBuyIn.show(min, max, total);
        }
        onTableGotSeatProfile: {
            seatByRemoteId(id).loadProfile(s);
        }

        onTableInit: {
            root.init();
        }
    }

    Connections {
        target: myApp
        onDisconnectedFromGamed: {
            dlgGamedDisconnect.open(qsTr("Disconnected from server"), qsTr("do you want to rejoin table") + "?");
        }
        onTableCommunityCards: {
            deck.flop(card1, card2, card3);
            deck.turn(card4);
            deck.river(card5);
        }
    }

    MouseArea {
        anchors.fill: parent
        onClicked: {
            dlgChat.close();
            menu.menuOff();
        }
    }


    //background image
    Image {
        source: "../../images/Table/bg.png"
        //anchors.fill: parent
        width: myApp.getWidth()
        height: myApp.getHeight()
    }

    Text {
        id: lblTax
        font.pixelSize: 10
        color: "white"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 270
    }


    Text {
        id: lblMainPot
        font.pixelSize: 16
        color: "white"
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -200
        anchors.top: tip.bottom
        text:""
    }

    Text {
        id: lblCall
        font.pixelSize: lblMainPot.font.pixelSize
        color: lblMainPot.color
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 100
        anchors.top: lblMainPot.top
        text: ""
    }

    SoundManager {
        id: sndPlayer
    }

    Deck {
        id: deck
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
    }

    TipBar {
        id: tip
        anchors.top: deck.bottom
        anchors.topMargin: 4
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Seat {
        id: seat1
        width: root.seat_width
        height: root.seat_height
        position: 1
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat1);
        }
    }
    Seat {
        id: seat2
        width: root.seat_width
        height: root.seat_height
        position: 2
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat2);
        }
    }

    Seat {
        id: seat3
        width: root.seat_width
        height: root.seat_height
        position: 3
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat3);
        }
    }

    Seat {
        id: seat4
        width: root.seat_width
        height: root.seat_height
        position: 4
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat4);
        }
    }

    Seat {
        id: seat5
        width: root.seat_width
        height: root.seat_height
        position: 5
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat5);
        }
    }

    Seat {
        id: seat6
        width: root.seat_width
        height: root.seat_height
        position: 6
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat6);
        }
    }

    Seat {
        id: seat7
        width: root.seat_width
        height: root.seat_height
        position: 7
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat7);
        }
    }

    Seat {
        id: seat8
        width: root.seat_width
        height: root.seat_height
        position: 8
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat8);
        }
    }

    Seat {
        id: seat9
        width: root.seat_width
        height: root.seat_height
        position: 9
        bar_chips.height: root.seat_bar_chips_height
        bar_chips_font_size: root.seat_bar_chips_font_size
        bar_title.height: root.seat_bar_title_height
        bar_title_name.font.pixelSize: root.seat_bar_title_name_font_size
        bar_title_action.font.pixelSize: root.seat_bar_title_action_font_size
        label_bet.width: seat_label_bet_width
        label_bet.height: seat_label_bet_height
        label_bet_font_size: seat_label_bet_font_size
        card_1.height: seat_card_height
        image_avatar.width: seat_avatar_width
        image_avatar.height: seat_avatar_height
        icon_cardbacks.height: root.seat_icon_cardsback_height
        chat_balloon.width: seat_chatballoon_width
        chat_balloon.height: seat_chatballoon_height
        chat_balloon_font_size: seat_chatballoon_font_size
        icon_gift.height: seat_gift_height
        icon_dealer_height: seat_icon_dealer_height
        button_sitdown_height: seat_button_sitdown_height
        onShowInfo: {
            dlgSeatInfo.show(seat9);
        }
    }

    WaitForOthersDialog {
        id: dlgWaitForOthers
        anchors.centerIn: parent
        visible: false
    }

    WaitForNextHandDialog {
        id: dlgWaitForNextHand
        anchors.centerIn: parent
        visible: false
    }

    NoEnoughChipsDialog {
        id: dlgNoEnoughChips
        anchors.centerIn: parent
        visible: false
        onStore: {
            myApp.goStorePage();
        }
        onClose: {
            myTable.showSitButtons();
        }
    }

    DailyBonusDialog {
        id: dlgDailyBonus
        anchors.centerIn: parent
        visible: false
        onClose: {
            myTable.showSitButtons();
        }
    }

    Menu {
        id: menu
        visible: true
        anchors.right: parent.right
        anchors.rightMargin: 10
        anchors.top: parent.top
        anchors.topMargin: - 12
        onLeaveGame: {
            console.log("leaveGame");
            if (myApp.getOfflineMode()) {
                myApp.goMainMenuPage();
            } else {
                myTable.usrWantQuit();
            }
        }
        onSoundOnOff: {
            console.log("soundOnOff");
            myApp.setSoundEffectEnable(on);
        }
        onVibraOnOff: {
            console.log("vibraOnOff");
            myApp.setVibraEnable(on);
        }
    }

    BetDialog {
        id: dlgBet
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: seat1.top
        anchors.bottomMargin: 40
        visible: false
        onBet: {
            myApp.tableUsrDidBet(value);
            soundPlay(params.getSoundIdBet());
        }
        onAllin: {
            myApp.tableUsrDidAllIn();
            soundPlay(params.getSoundIdAllIn());
        }
        onCancel: {
            myTable.usrDidCancelBet();
        }
    }

    SeatInfoDialog {
        id: dlgSeatInfo
        visible: false
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        onSendChips: {
            if (myTable.isVisitorMode())
                return;
            hide();
            dlgSendChips.hide();
            dlgGiftStore.hide();
            dlgSendChips.show(i, myTable.getSendChipsLimit());
        }
        onSendGift: {
            if (myTable.isVisitorMode())
                return;
            hide();
            dlgSendChips.hide();
            dlgGiftStore.hide();
            dlgGiftStore.show(i);
        }
        onClosed: {
            dlgSendChips.hide();
            dlgGiftStore.hide();
        }
    }

    SendChipsDialog {
        id: dlgSendChips
        anchors.horizontalCenter: parent.horizontalCenter
        visible: false
        onSend: {
            myApp.tableUsrDidSendChipsForSeat(seat, chips);
        }
    }

    GiftStoreDialog {
        id: dlgGiftStore
        anchors.horizontalCenter: parent.horizontalCenter
        visible: false
        onBuyFood: {
            myApp.tableUsrDidBuyFoodForSeat(seat, food);
        }
        onBuyDrink: {
            myApp.tableUsrDidBuyDrinkForSeat(seat, drink);
        }
    }

    ActionBar {
        id: actionBar
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.leftMargin: 200
        height: 50
        visible: false
        onFold: {
            hide();
            soundPlay(params.getSoundIdFold())
            myApp.tableUsrDidFold();

        }
        onCheck: {
            hide();
            soundPlay(params.getSoundIdCheck())
            myApp.tableUsrDidCheck();
        }
        onCall: {
            hide();
            soundPlay(params.getSoundIdCall())
            myApp.tableUsrDidCall();
        }
        onBet: {
            myTable.usrWantBet();
        }
        onRaise: {
            myTable.usrWantRaise();
        }
    }

    ImageButton {
        id: btnChat
        width: 48
        height: width
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 40
        source: "../../images/Table/btn_chat.png"
        onClicked: {
            dlgChat.open()
        }
    }

    ChatDialog {
        id: dlgChat
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: 60
        visible: false
        onChat: {
            myApp.tableUsrDidChat(s);
        }
    }

    QueryDialog {
        id: dlgQuit
        visible: false
        text_cancel: qsTr("Cancel")
        text_ok: qsTr("Ok")
        onOk: {
            close();
            tip.show("Please wait...", 5);
            myApp.tableUsrDidQuit();
        }
        onCancel: {
            close();
        }
    }

    QueryDialog {
        id: dlgGamedDisconnect
        visible: false
        onOk: {
            close();
            console.log("usr want rejoin");
            myApp.goMainMenuPage();
            myApp.mainmenuPlayNow();
        }
        onCancel: {
            close();
            myApp.goMainMenuPage();
        }
    }

    ServerNoServiceDialog {
        id: dlgServerNoService
        anchors.centerIn: parent
        visible: false
    }

    Button {
        id: btnTest
        height: 64
        width: height
        color: "blue"
        text: "T"
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.leftMargin: 80
        anchors.bottomMargin: 10
        visible: myApp.getOfflineMode()
        onClicked: {
            myApp.tableTest();
        }
    }

    BuyInDialog {
        id: dlgBuyIn
        visible: false
        onBuyin: {
            myTable.hideSitButtons();
            myApp.tableUsrDidBuyInWith(value);
        }
        onGetChips: {
            myApp.goStorePage();
        }
        onCancel: {
            myTable.showSitButtons()
        }
    }

    function setSize(t) {
        root.table_size = t;
        seat1.visible = false;
        seat2.visible = false;
        seat3.visible = false;
        seat4.visible = false;
        seat5.visible = false;
        seat6.visible = false;
        seat7.visible = false;
        seat8.visible = false;
        seat9.visible = false;

        seat1.resetPosition(t);
        seat1.visible = true;
        seat2.resetPosition(t);
        seat2.visible = true;
        seat3.resetPosition(t);
        seat3.visible = true;
        seat4.resetPosition(t);
        seat4.visible = true;
        seat5.resetPosition(t);
        seat5.visible = true;

        if (t === params.getTableSize9()) {
            seat6.resetPosition(t);
            seat6.visible = true;
            seat7.resetPosition(t);
            seat7.visible = true;
            seat8.resetPosition(t);
            seat8.visible = true;
            seat9.resetPosition(t);
            seat9.visible = true;
        }

    }

    function joinWithSeat(seat_id) {
        var offset = seat_id - 1;
        seat1.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat1.position, offset);
        seat2.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat2.position, offset);
        seat3.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat3.position, offset);
        seat4.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat4.position, offset);
        seat5.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat5.position, offset);
        seat6.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat6.position, offset);
        seat7.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat7.position, offset);
        seat8.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat8.position, offset);
        seat9.remote_id = myTable.getRealIdWithSeatPositionAndOffset(seat9.position, offset);

    }

    function seatByPosition(i) {
        switch (i) {
        case 1:
            return seat1;
        case 2:
            return seat2;
        case 3:
            return seat3;
        case 4:
            return seat4;
        case 5:
            return seat5;
        case 6:
            return seat6;
        case 7:
            return seat7;
        case 8:
            return seat8;
        case 9:
            return seat9;
        default:
            return null;
        }
    }

    function seatByRemoteId(i) {
        if (seat1.remote_id === i)
            return seat1;
        if (seat2.remote_id === i)
            return seat2;
        if (seat3.remote_id === i)
            return seat3;
        if (seat4.remote_id === i)
            return seat4;
        if (seat5.remote_id === i)
            return seat5;
        if (seat6.remote_id === i)
            return seat6;
        if (seat7.remote_id === i)
            return seat7;
        if (seat8.remote_id === i)
            return seat8;
        if (seat9.remote_id === i)
            return seat9;
        return null;
    }

    function sendChipsDone(seat, chips) {
        seatByRemoteId(seat).didBuyChips(chips);
    }

    function sendGiftFoodDone(seat, food) {
        seatByRemoteId(seat).gift_src = params.getFoodImagePath(food);
    }

    function sendGiftDrinkDone(seat, drink) {
        seatByRemoteId(seat).gift_src = params.getDrinkImagePath(drink);
    }

    function handclean() {
        deck.clear();
        tip.hide();
        actionBar.hide()
        seat1.handClean();
        seat2.handClean();
        seat3.handClean();
        seat4.handClean();
        seat5.handClean();
        if (root.table_size === params.getTableSize9()) {
            seat6.handClean();
            seat7.handClean();
            seat8.handClean();
            seat9.handClean();
        }

        updateCall(0);
        updateMainPot(0);

    }

    function updateCall(c) {
        lblCall.text = qsTr("Call") + ": " + c;
        lblCall.visible = c > 0;
    }
    function updateMainPot(c) {
        lblMainPot.text = qsTr("MainPot") + ": " + c;
        lblMainPot.visible = c > 0;
    }

    function soundPlay(i)
    {
        if (myApp.getBackgroundMode() || myApp.getSilentMode() || !menu.sound_enable)
            return;
        sndPlayer.play(i);
    }

    function init() {
        seat1.didLeave();
        seat2.didLeave();
        seat3.didLeave();
        seat4.didLeave();
        seat5.didLeave();
        if (myTable.getSize() === params.getTableSize9()) {
            seat6.didLeave();
            seat7.didLeave();
            seat8.didLeave();
            seat9.didLeave();
        }
        handclean();
    }
}
